%Example of user input MATLAB file for MCR post processing
%filename = ['savedData',sprintf('%03d', imcr),'.mat'];
filename = sprintf('HERO2024Hyd%03d.mat', imcr);
% filename = sprintf('w%01dP3A3.mat', imcr);

x_width = 3.25 ;
y_height = 2.5;
FS = 8;         

t1=simu.rampTime;             %time after ramp
t2=simu.endTime;             %end of analysis

V = InVel((t1/simu.dt):(t2/simu.dt));
F = -SimTension((t1/simu.dt):(t2/simu.dt));
F = max(F,0);
 
mcr.AvgProduced(imcr) = mean(SimQp((t1/simu.dt):(t2/simu.dt)))*15850.323;       %store average permeate production [gpm]
mcr.AvgFeed(imcr) = mean(SimQfeed((t1/simu.dt):(t2/simu.dt)))*15850.323;        %store average feed flow before accumulators [gpm]
mcr.AvgROFeed(imcr) = mean(SimQfeedRO((t1/simu.dt):(t2/simu.dt)))*15850.323;    %store average feed flow after acccumulators (clark pump inlet) [gpm]
mcr.AvgPumpQ(imcr) = mean(SimQpump((t1/simu.dt):(t2/simu.dt)))*15850.323;       %store average pump output flow [gpm]
mcr.AvgPress(imcr) = mean(SimPfeed((t1/simu.dt):(t2/simu.dt)))*0.000145038;     %store average feed pressure [psi]
mcr.AvgMechPower(imcr) = mean(F.*V);                                            %Average mechanical power input [Watts]
mcr.AvgPumpPower(imcr) = mean(SimQpump((t1/simu.dt):(t2/simu.dt)).*SimPpump((t1/simu.dt):(t2/simu.dt)));         %Average Hydraulic power at pump output [Watts]
mcr.AvgROPower(imcr) =   mean(SimQfeed((t1/simu.dt):(t2/simu.dt)).*SimPfeed((t1/simu.dt):(t2/simu.dt)));           %Average Hydraulic power at RO Feed [Watts]
mcr.Avgwinchten(imcr) = -mean(SimTension((t1/simu.dt):(t2/simu.dt)))*0.224809;        % [lbf] Average winch line tension
mcr.Maxwinchten(imcr) = -min(SimTension((t1/simu.dt):(t2/simu.dt)))*0.224809;         % [lbf] Maximum winch line tension
mcr.Maxpermeate(imcr) = max(SimQp((t1/simu.dt):(t2/simu.dt)))*15850.323;        % [gpm] peak rate of permeate production

mcr.time = output.bodies.time';                                        %Store Time array [s]
mcr.watersurface = output.wave.elevation';                             %Store Wave Elevation [m]
mcr.WECheave = output.bodies.position(:,3)';                           %Store WEC heave position [m]   
mcr.velheave = InVel';                                                 %store input velocity at winch [m/s]winchtension(imcr) = SimTension*0.224809';                               %store tension on winch cable [lbf]
mcr.winchpos = SimPos';                                                %store winch position [rad]
mcr.winchvel = SimWinw;                                                %store winch velocity [rad/s]
mcr.winchten = SimTension*0.224809';                                   %store winch tension [lbf] 
mcr.SimQpump = SimQpump*15850.323';                                    %store pump flow [gpm]
mcr.SimPpump = SimPpump*0.000145038';                                  %store pump output pressure [psi]
mcr.SimPumpw = SimPumpw;                                               %store pump velocity [rad/s]
mcr.SimQfeed = SimQfeed*15850.323';                                    %store RO feed flow (Pre-accumulator) [gpm]
mcr.SimQfeedRO = SimQfeedRO*15850.323';                                %store RO feed flow (Post-accumulator clark pump inlet) [gpm]
mcr.SimPfeed = SimPfeed*0.000145038';                                  %store RO feed pressure [psi]
mcr.SimQp = SimQp*15850.323';                                          %store RO permeate flow [gpm]

save (filename, 'mcr','output','waves');

if imcr == length(mcr.cases);
    H = mcr.cases(:,1);
    T = mcr.cases(:,2);
 

figure;
MatPumpQ=reshape(mcr.AvgPumpQ,[l_waveperiod,l_waveheight])'
heatmap(MatPumpQ,XData=unique(T),YData=unique(H))'
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Pump Output [gpm]')

figure;
MatFeedQRO=reshape(mcr.AvgROFeed,[l_waveperiod,l_waveheight])'
heatmap(MatFeedQRO,XData=unique(T),YData=unique(H))'
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average RO Feed Flow (Post-Accumulator) [gpm]')

figure;
MatFeedQ=reshape(mcr.AvgFeed,[l_waveperiod,l_waveheight])'
heatmap(MatFeedQ,XData=unique(T),YData=unique(H))'
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average RO Feed Flow (Pre-Accumulator) [gpm]')

figure;
MatFeedP=reshape(mcr.AvgPress,[l_waveperiod,l_waveheight])'
heatmap(MatFeedP,XData=unique(T),YData=unique(H))
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Feed Pressure [psi]')

figure;
MatPermQ=reshape(mcr.AvgProduced,[l_waveperiod,l_waveheight])'
heatmap(MatPermQ,XData=unique(T),YData=unique(H))'
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Water Production [gpm]')
% set(gcf, 'PaperUnits', 'inches');
% set(gcf, 'PaperPosition', [0 0 x_width y_height]); 
% saveas(gcf,strcat(PumpVol + "L Pump AVG Permeate Production.png"))

figure;
MatPowAbs=reshape(mcr.AvgMechPower,[l_waveperiod,l_waveheight])'
heatmap(MatPowAbs,XData=unique(T),YData=unique(H))
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Mechanical Power input [Watts]')

figure;
MatPowPump=reshape(mcr.AvgPumpPower,[l_waveperiod,l_waveheight])'
heatmap(MatPowPump,XData=unique(T),YData=unique(H))
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Hydraulic Power at Pump [Watts]')

figure;
MatPowROi=reshape(mcr.AvgROPower,[l_waveperiod,l_waveheight])'
heatmap(MatPowROi,XData=unique(T),YData=unique(H))
xlabel('Tp [s]')
ylabel('Hs [m]')
title('Average Hydraulic Power RO Input [Watts]')

% figure;
% Tensionmat=reshape(mcr.Avgwinchten,[l_waveperiod,l_waveheight])'
% heatmap(Tensionmat,XData=unique(T),YData=unique(H))'
% xlabel('Tp [s]')
% ylabel('Hs [m]')
% title('Average Winch Line Tension [lbf]')
% set(gcf, 'PaperUnits', 'inches');
% set(gcf, 'PaperPosition', [0 0 x_width y_height]); 
% saveas(gcf,strcat(PumpVol + "L Pump Avg Anchor Load.png"))

% figure;
% Tensionmat1=reshape(mcr.Maxwinchten,[l_waveperiod,l_waveheight])'
% heatmap(Tensionmat1,XData=unique(T),YData=unique(H))'
% xlabel('Tp [s]')
% ylabel('Hs [m]')
% title('Maximum Winch Line Tension [lbf]')
% set(gcf, 'PaperUnits', 'inches');
% set(gcf, 'PaperPosition', [0 0 x_width y_height]); 
% saveas(gcf,strcat(PumpVol + "L Pump Peak Anchor Load.png"))

% figure;
% Maxpermeatemat=reshape(mcr.Maxpermeate,[l_waveperiod,l_waveheight])'
% heatmap(Maxpermeatemat,XData=unique(T),YData=unique(H))'
% xlabel('Tp [s]')
% ylabel('Hs [m]')
% title('Maximum Rate of Permeate Production [gpm]')
% set(gcf, 'PaperUnits', 'inches');
% set(gcf, 'PaperPosition', [0 0 x_width y_height]); 
% saveas(gcf,strcat(PumpVol + "L Pump Peak Permeate Volume.png"))

end




