%% 18inch GEN 1
%% 100%  
cg = -.0955;                            %new cg 
%  Remember to adjust user defined functions
%%
rho = 1000;
g = 9.81;

PumpVol = 0.351;                        % [L/rev] Pump displacement

%% Simulation Data
simu = simulationClass();               % Initialize Simulation Class
simu.simMechanicsFile = 'HERO_HPTO_2024_07_02_24.slx';

simu.solver = 'ode4';                   % simu.solver = 'ode4' for fixed step & simu.solver = 'ode45' for variable step 
simu.explorer='off';                    % Turn SimMechanics Explorer (on/off)
simu.startTime = 0;                     % Simulation Start Time [s]
simu.rampTime = 100;                    % Wave Ramp Time Length [s]
simu.endTime = 3100; %;                 % Simulation End Time [s]
simu.dt = 0.005; 						% Simulation time-step [s]

%% Wave Information 

% % No wave condition
% waves = waveClass('noWave');               % Initialize Wave Class and Specify Type
% waves.period = 9;                          % Wave Period [s]

% %Regular Waves
% waves = waveClass('regular');              % Initialize Wave Class and Specify Type
% waves.height = 1;                        % Wave Height [m]
% waves.period = 12;                         % Wave Period [s]         

% % Regular Waves with CIC
% waves = waveClass('regularCIC');           % Initialize Wave Class and Specify Type                                 
% waves.height = 0.75;                        % Wave Height [m]
% waves.period = 9;                         % Wave Period [s]

% Irregular Waves using PM Spectrum 
waves = waveClass('irregular');           % Initialize Wave Class and Specify Type
waves.height = [.25:.25:3.75];                      % Significant Wave Height [m]
waves.period = [5:1:13];                         % Peak Period [s]
waves.spectrumType = 'PM';                % Specify Wave Spectrum Type
waves.phaseSeed = 1;                      % Phase is seeded so eta is the same

% % Irregular Waves using JS Spectrum with Equal Energy and Seeded Phase
% waves = waveClass('irregular');           % Initialize Wave Class and Specify Type
% waves.height = 2.5;                       % Significant Wave Height [m]
% waves.period = 8;                         % Peak Period [s]
% waves.spectrumType = 'JS';                % Specify Wave Spectrum Type
% waves.bem.option = 'EqualEnergy';         % Uses 'EqualEnergy' bins (default) 
% waves.phaseSeed = 1;                      % Phase is seeded so eta is the same

% % Irregular Waves using PM Spectrum with Traditional and State Space 
% waves = waveClass('irregular');           % Initialize Wave Class and Specify Type
% waves.height = 2.5;                       % Significant Wave Height [m]
% waves.period = 8;                         % Peak Period [s]
% waves.spectrumType = 'PM';                % Specify Wave Spectrum Type
% simu.stateSpace = 1;                      % Turn on State Space
% waves.bem.option = 'Traditional';         % Uses 1000 frequnecies

% % Irregular Waves with imported spectrum
% waves = waveClass('spectrumImport');      % Create the Wave Variable and Specify Type
% waves.spectrumFile = 'spectrumData.mat';  % Name of User-Defined Spectrum File [:,2] = [f, Sf]

% % Waves with imported wave elevation time-history  
% waves = waveClass('elevationImport');          % Create the Wave Variable and Specify Type
% waves.elevationFile = 'elevationData.mat';     % Name of User-Defined Time-Series File [:,2] = [time, eta]


%% Body Data
% Float
body(1) = bodyClass('hydroData/herowec.h5');    	
body(1).geometryFile = 'geometry/18inch.stl'; 

% body(1).initial.displacement=([0,0,0]);       %Use this for Free-Decay

%%  MOI - Rhino
MOIx = 0.124695 * rho;
MOIy = MOIx;
MOIz = 0.246465 * rho;
body(1).inertia = [MOIx MOIy MOIz];   


%% Constraint Parameters
% Floating (3DOF) Joint
constraint(1) = constraintClass('Constraint1'); 
constraint(1).location = [0 0 -3];              %Approximate anchor location

constraint(2) = constraintClass('Constraint2'); 
constraint(2).location = [0 0 cg];   

%% PreTension
%k = 0;  %N/m  SPRING (was 100)
% pretension = 100 * 0.45359237 * g;  %100 lbf x conversion
%pretension = 0;  

orig_mass = 0.3976 * rho; %kg  % Wamit displacement  

%body(1).mass = orig_mass - pretension / g;
body(1).mass = orig_mass;

%% Translational PTO
pto(1) = ptoClass('PTO1');           	% Initialize PTO Class for PTO1
pto(1).location = [0 0 -1];             % PTO Location [m]


% pto_control.k =  k;
% pto_control.pretension = pretension;
% pto_control.eqPosition = pto_control.pretension./pto_control.k;

%%
simu.cicEndTime = 60;                  %tweak cicEndTime from default 60s
l_waveheight=length(waves.height);     %makes vector for post processing
l_waveperiod=length(waves.period);     %makes vector for post processing

%% Visualization Parameters
simu.domainSize=10;


